#include "bits/stdc++.h"

using namespace std;

#define MAX_WORD_LEN 21
#define ALPHABET_SIZE 93

struct TrieNode {
    int counter;
    int alphabetSize;

    int isEnd;
    struct TrieNode *parent;
    struct TrieNode **arcs;
};

struct TrieNode *createTrieRoot(int alpabetSize) {
    TrieNode *newRoot = (TrieNode *)malloc(sizeof(TrieNode));
    //-proverka

    newRoot->alphabetSize = alpabetSize;
    newRoot->isEnd = 0;
    newRoot->counter = 0;
    newRoot->parent = NULL;
    newRoot->arcs = (TrieNode **)calloc(alpabetSize, sizeof(TrieNode *));
    //-proverka

    return newRoot;
}

struct TrieNode *descend(TrieNode *root, const char *key, int len, int *index, int addMode) {
    int i;
    for (i = 0; i < len; i++) {
        root->counter += addMode;
        if (root->arcs[key[i] - 33] == NULL) break;
        root = root->arcs[key[i] - 33];
    }

    if (i == len) {
        root->counter = addMode;
    }

    if (index != NULL) {
        *index = i;
    }

    return root;
}

int prefix(TrieNode *root, const char *key, int len) {
    int index;
    TrieNode *result = descend(root, key, len, &index, 0);
    if (index != strlen(key)) {
        return 0;
    }

    return result->counter;
}

void insert(TrieNode *root, const char *key, int len) {
    int index;
    TrieNode *result = descend(root, key, len, &index, 1);

    if (index == len && result->isEnd) {
        while (result != NULL) {
            result->counter--;
            result=result->parent;
        }

        return;
    }

    TrieNode *newNode;
    for (; index < len; index++) {
        newNode = createTrieRoot(root->alphabetSize);
        newNode->counter = 1;
        result->arcs[key[index] - 33] = newNode;
        newNode->parent = result;
        result = newNode;
    }

    result->isEnd = 1;
}

void deleteTrie(TrieNode *root) {
    for (int i = 0; i < root->alphabetSize; i++) {
        if (root->arcs[i] != NULL) {
            deleteTrie(root->arcs[i]);
        }
    }

    free(root->arcs);
    free(root);
}

enum TokenType{
    RESERVED = 0,
    NUMBER,
    WORD,
    END,
};

struct Token {
    string inner;
    TokenType type;

    Token(const string &substr, TokenType t) :
        inner(substr), type(t)
    {};
};

class Tokenizer {
public:
    Tokenizer(const string &str, TrieNode *r);

    Token next();
//    Token peek();
private:
    string expression;
    int currentPos;

    TrieNode *root;
    bool isEnd;
};

Tokenizer::Tokenizer(const string &str, TrieNode *r)
    : expression(str), currentPos(0), root(r) {}

Token Tokenizer::next() {
    TrieNode *currentRoot = root;

    if (isEnd) {
        return Token("", TokenType::END);
    }

    //пробелы
    while (currentPos < expression.size() && isspace(expression[currentPos])) currentPos++;
    //коммент
    if (currentPos < expression.size() && expression[currentPos] == '#') {
        while (currentPos < expression.size() && expression[currentPos] != '\n') currentPos++;
    }
    if (currentPos == expression.size()) {
        isEnd = true;
        return Token("", TokenType::END);
    }

    int r = currentPos;
    while(r < expression.size()
        && (isalnum(expression[r]) || expression[r] == '_' || expression[r] == '$')) r++;

    bool flag0 = false;
    int l = r - currentPos;
    if (l == 0){
        flag0 = true;
        l++;
    }
    string tokenStr = expression.substr(currentPos, l);

    bool is_prefix = true;
    int index;
    TrieNode *result = descend(currentRoot, tokenStr.c_str(), tokenStr.length(), &index, 0);
    if (index != strlen(tokenStr.c_str())) {
        is_prefix = false;
    }

    if (!is_prefix) {
        if (isdigit(expression[currentPos])) {
            currentPos = (flag0 ? r + 1 : r);
            return Token(tokenStr, NUMBER);
        }

        currentPos = (flag0 ? r + 1 : r);
        return Token(tokenStr, WORD);
    }

    int lastEndIndex = r;
    while (r < expression.size() && !isspace(expression[r]) && expression[r] != '#') {
        if (currentRoot->arcs[expression[r] - 33] == NULL) break;
        currentRoot = currentRoot->arcs[expression[r] - 33];
        if (currentRoot->isEnd) {
            lastEndIndex = r;
        }
    }

    l = lastEndIndex - currentPos;
    if (l == 0){
        flag0 = true;
        l++;
    };
    tokenStr = expression.substr(currentPos, l);
    currentPos = (flag0 ? lastEndIndex + 1 : lastEndIndex);

    //ррррря
    return Token(tokenStr, TokenType::RESERVED);
}

//Token Tokenizer::peek() {
//
//}


int main() {
    TrieNode *root = createTrieRoot(ALPHABET_SIZE);

    int n;
    cin >> n;
    string inpt;
    for (int i = 0; i < n; i++) {
        cin >> inpt;
        insert(root, inpt.c_str(), inpt.length());
    }

    string expression;
    char line[81];
    int m;
    cin >> m;
    cin.get();
    for (int i = 0; i < m; i++) {
        cin.getline(line, 82, '\n');
        for (int j = 0; j < 82 && line[j] != '#' && line[j] != '\0'; j++) {
            expression.push_back(line[j]);
        }
    }

    long long code = 0;
    unordered_map<string, string> newNames;
    Tokenizer tokenizer(expression, root);
    while(true) {
        auto newToken = tokenizer.next();
        if (newToken.type == TokenType::END) {
            break;
        }

       if (newToken.type == TokenType::WORD) {
           string newName = "";
           long long tmpCode = code;
           while(tmpCode != 0) {
                newName.push_back('a' + (int)(tmpCode % 26));
                tmpCode /= 26;
           }
           newNames.insert({newToken.inner, newName});
           code++;
       }
    }

    deleteTrie(root);
    return 0;
}