#include <bits/stdc++.h>
using namespace std;

#ifdef mypity
#define debug(...) fprintf(stderr, __VA_ARGS__);
#define cdebug(...) cerr << __VA_ARGS__;
#else
#define debug(...) do {} while(false)
#define cdebug(...) do {} while(false)
#endif

using i64 = int64_t;

#define WHOLE(x) (x).begin(),(x).end()
#define int long long

struct part {
  vector<int> arrive;
  vector<int> dur;
  vector<int> threshold;
  vector<int> y;

  part() = default;

  part(const vector< pair<int, int> > &p, int l, int r) {
    r = min(r, (int) p.size());
    arrive.resize(r - l);
    dur.resize(r - l);
    threshold.resize(r - l);
    y.resize(r - l);
    for (int i = 0; i < (r - l); ++i) {
      arrive[i] = p[l + i].first;
      dur[i] = p[l + i].second;
    }
    recalc(0);
  }

  int sz() const {
    return (int) arrive.size();
  }

  int first() const {
    return arrive.empty() ? 0 : arrive[0];
  }

  int last() const {
    return arrive.empty() ? 0 : arrive.back();
  }

  void recalc(int from) {
    for (int i = from; i < (int) arrive.size(); ++i) {
      int touch = i == 0 ? 0 : threshold[i - 1];
      int baseEnd = i == 0 ? 0 : y[i - 1];
      if (baseEnd >= arrive[i]) {
        threshold[i] = 0;
        y[i] = baseEnd + dur[i];
      }
      else {
        int delta = arrive[i] - baseEnd;
        threshold[i] = touch + delta;
        y[i] = arrive[i] + dur[i];
      }
    }
  }

  void add(int t, int d) {
    int idx = lower_bound(WHOLE(arrive), t) - arrive.begin();
    arrive.insert(arrive.begin() + idx, t);
    dur.insert(dur.begin() + idx, d);
    threshold.insert(threshold.begin() + idx, 0);
    y.insert(y.begin() + idx, 0);
    recalc(idx);
  }

  int endT(int startT) {
    if (arrive.empty()) return 0;
    int idx = (int) threshold.size() - 1;
    if (startT <= threshold[idx]) {
      return y[idx];
    }
    return (startT - threshold[idx]) + y[idx];
  }

  void del(int t) {
    int idx = lower_bound(WHOLE(arrive), t) - arrive.begin();
    assert(idx >= 0 && idx < sz());
    arrive.erase(arrive.begin() + idx);
    dur.erase(dur.begin() + idx);
    threshold.erase(threshold.begin() + idx);
    y.erase(y.begin() + idx);
    recalc(idx);
  }

  int query(int t, int s) {
    int lastt = t;
    for (int i = 0; i < sz(); ++i) {
      if (arrive[i] <= s) {
        if (threshold[i] >= t) {
          lastt = y[i];
        } else {
          lastt = y[i] + (t - threshold[i]);
        }
      } else {
        break;
      }
    }
    return lastt;
  }
};

const int PSZ = 512;
const int REBUILD = 512;

vector<part> parts;

void rebuild() {
  vector< pair<int, int> > raw;
  for (int i = 0; i < (int) parts.size(); ++i) {
    for (int j = 0; j < parts[i].sz(); ++j) {
      raw.emplace_back(parts[i].arrive[j], parts[i].dur[j]);
    }
  }
  parts.clear();
  if (raw.empty()) parts.resize(1);
  else {
    for (int i = 0; i < (int) raw.size(); i += PSZ) {
      parts.emplace_back(raw, i, i + PSZ);
    }
  }
}

signed main() {
#ifdef mypity
  freopen("G.in", "r", stdin);
#endif
  cin.sync_with_stdio(false);
  cin.tie(nullptr);
  int q;
  cin >> q;
  parts.resize(1);
  vector<int> queries;
  int badq = 0;
  for (int it = 0; it < q; ++it) {
    char c;
    cin >> c;
    if (c == '?') {
      int t;
      cin >> t;
      queries.push_back(0);
      int curt = 0, ans = -1;
      for (int i = 0; i < (int) parts.size(); ++i) {
        if (parts[i].last() <= t) {
          curt = parts[i].endT(curt);
        } else {
          curt = parts[i].query(curt, t);
          break;
        }
      }
//      if (it == 8) {
//        for (int i = 0; i < parts.size(); ++i) {
//          for (int j = 0; j < parts[i].sz(); ++j) {
//            cout << "i: " << i << " " << parts[i].arrive[j] << " " << parts[i].dur[j]
//            << " " << parts[i].threshold[j] << " " << parts[i].y[j] << endl;
//          }
//          cout << "========" << endl;
//        }
//      }
      cout << max(0LL, curt - t) << "\n";
    } else if (c == '+') {
      int t, d;
      cin >> t >> d;
      queries.push_back(t);
      int i;
      for (i = 0; i < (int) parts.size(); ++i) {
        if (parts[i].last() >= t) {
          break;
        }
      }
      if (i == (int) parts.size()) --i;
      assert(i >= 0 && i < (int) parts.size());
      parts[i].add(t, d);
      badq++;
    } else if (c == '-') {
      int id;
      cin >> id;
      queries.push_back(-1);
      int t = queries[id - 1];

      int i;
      for (i = 0; i < (int) parts.size(); ++i) {
        if (parts[i].first() > t) {
          break;
        }
      }
      --i;
      assert(i >= 0 && i < (int) parts.size());
      parts[i].del(t);
    }
    if (badq % REBUILD == 0) {
      rebuild();
    }
  }
}