#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <set>
#include <queue>
#include <functional>
#include <string>

#include <ctime>

using namespace std;


template<class T>
using minheap = priority_queue<T, vector<T>, greater<T>>;


void Floyd (vector<vector<int>> &matr)
{
    for (size_t k = 0; k < matr.size (); k++)
        for (size_t i = 0; i < matr.size (); i++)
            for (size_t j = 0; j < matr.size (); j++)
                matr[i][j] = min (matr[i][j], matr[i][k] + matr[k][j]);
}


void dfs (const vector<vector<int>> &gr, vector<bool> &used, vector<int> &ord, int v)
{
    if (used[v])
        return;

    used[v] = true;

    for (int i = 0; i < gr.size (); i++)
        if (gr[v][i] == 0)
            dfs (gr, used, ord, i);

    ord.push_back (v);
}


void solve (istream &cin = std::cin, ostream &cout = std::cout)
{
    int n;

    cin >> n;

    vector<vector<int>> matr (n, vector<int> (n));

    for (auto &row : matr)
        for (auto &it : row)
        {
            cin >> it;
            it ^= 1;
        }

    Floyd (matr);

    vector<int> ord;
    vector<bool> used (n);

    for (int i = 0; i < matr.size (); i++)
        dfs (matr, used, ord, i);

    vector<vector<int>> layers = { {ord.front ()} };

    for (int i = 1; i < ord.size (); i++)
    {
        if (matr[layers.back ().back ()][ord[i]] == 1)
            layers.emplace_back ();

        layers.back ().push_back (ord[i]);
    }

    reverse (layers.begin (), layers.end ());

    cout << "10 2 " << 2 * layers.size () << endl;

    for (int i = 0; i < 2 * layers.size (); i++)
    {
        vector<string> field (2, string (10, i % 2 == 0 ? '.' : '#'));

        if (i % 2 == 1)
        {
            if (i % 4 == 1)
                field[0][0] = '.';
            else
                field[0][1] = '.';
        }
        else
        {
            for (int j = 0; j < layers[i / 2].size (); j++)
                field[1][j] = layers[i / 2][j] + '1';
        }

        for (const auto &it : field)
            cout << it << endl;
        cout << endl;
    }
}


int main ()
{
    ios_base::sync_with_stdio (false);
    cin.tie (nullptr);

#ifdef LOCAL
    ifstream fin ("input.txt");

    solve (fin);

    cout << "clock: " << clock () / (double)CLOCKS_PER_SEC << endl;
#else
    solve ();
#endif // LOCAL

    return 0;
}
