#include <iostream>
#include <fstream>
#include <vector>
#include <algorithm>
#include <set>
#include <queue>
#include <functional>
#include <string>

#include <ctime>

using namespace std;


template<class T>
using minheap = priority_queue<T, vector<T>, greater<T>>;


void Floyd (vector<vector<int>> &matr)
{
    for (size_t k = 0; k < matr.size (); k++)
        for (size_t i = 0; i < matr.size (); i++)
            for (size_t j = 0; j < matr.size (); j++)
                matr[i][j] = min (matr[i][j], matr[i][k] + matr[k][j]);
}


void dfs (const vector<vector<int>> &gr, vector<bool> &used, vector<int> &ord, int v)
{
    if (used[v])
        return;

    used[v] = true;

    for (int i = 0; i < gr.size (); i++)
        if (gr[v][i] == 0)
            dfs (gr, used, ord, i);

    ord.push_back (v);
}


void solve (istream &cin = std::cin, ostream &cout = std::cout)
{
    int n;

    cin >> n;

    vector<vector<int>> matr (n, vector<int> (n));

    for (auto &row : matr)
        for (auto &it : row)
        {
            cin >> it;
            it ^= 1;
        }

    Floyd (matr);

    vector<int> ord;
    vector<bool> used (n);

    for (int i = 0; i < matr.size (); i++)
        dfs (matr, used, ord, i);

    vector<vector<int>> layers = { {ord.front ()} };
    vector<int> labels = { ord.front () };

    for (int i = 1; i < ord.size (); i++)
    {
        int t = 0;
        while (t < i && (matr[ord[t]][ord[i]] == 1 || matr[ord[i]][ord[t]] == 1))
            t++;

        if (t == i)
        {
            layers.emplace_back ();
            layers.back ().push_back (ord[i]);
            labels.push_back (ord[i]);
        }
        else
            layers[find (labels.begin (), labels.end (), ord[t]) - labels.begin ()].push_back (ord[i]);
    }

    for (auto row : layers)
    {
        for (auto it : row)
            cerr << it << ' ';
        cerr << endl;
    }

    reverse (layers.begin (), layers.end ());
    reverse (labels.begin (), labels.end ());

    cout << "20 3 " << 2 * layers.size () + 1 << endl;

    for (int i = 0; i < 2 * layers.size (); i++)
    {
        vector<string> field (3, string (20, i % 2 == 0 ? '.' : '#'));

        for (int i = 0; i < field[0].size (); i++)
            field[0][i] = i % 2 == 0 ? '.' : '#';

        if (i % 2 == 1)
            field[0][i - 1] = '#';
        else
        {
            for (int j = 0; j < labels.size (); j++)
                if (matr[labels[i / 2]][j] == 1)
                    field[1][2 * j] = '#';
            field[1][i] = '.';
            for (int j = 0; j < layers[j / 2].size (); j++)
                field[2][j] = layers[i / 2][j] + '1';
        }

        for (const auto &it : field)
            cout << it << endl;
        cout << endl;
    }

    vector<string> bot (3, string (20, '.'));

    for (const auto &it : bot)
        cout << it << endl;
    cout << endl;
}


int main ()
{
    ios_base::sync_with_stdio (false);
    cin.tie (nullptr);

#ifdef LOCAL
    ifstream fin ("input.txt");

    solve (fin);

    cout << "clock: " << clock () / (double)CLOCKS_PER_SEC << endl;
#else
    solve ();
#endif // LOCAL

    return 0;
}
