#include <bits/stdc++.h>

#define all(x) (x).begin(), (x).end()

using li = long long;
using ld = long double;

void solve(bool read);

using namespace std;

int main() {
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
#else
    cin.tie(nullptr);
    ios_base::sync_with_stdio(false);
#endif

    solve(true);

#ifdef LOCAL
    cerr << endl << endl << clock() / (double)CLOCKS_PER_SEC << endl;
#endif

    return 0;
}

const li inf = 1e18;

struct SegTree {
    int n;
    vector<li> a;
    vector<li> to_add;

    SegTree(int _n) {
        n = 1;
        while (n < _n) {
            n *= 2;
        }
        a.resize(n + n, -inf);
        to_add.resize(n + n, 0);
    }

    void relax(int v) {
        if (to_add[v]) {
            a[v + v] += to_add[v];
            a[v + v + 1] += to_add[v];
            to_add[v + v] += to_add[v];
            to_add[v + v + 1] += to_add[v];
            to_add[v] = 0;
        }
    }

    li get(int v, int l1, int r1, int l, int r) {
        if (l >= r1 || l1 >= r) {
            return -inf;
        }
        if (l <= l1 && r >= r1) {
            return a[v];
        }
        relax(v);
        int m = (l1 + r1) / 2;
        return max(get(v + v, l1, m, l, r), get(v + v + 1, m, r1, l, r));
    }

    li get(int l, int r) {
        return get(1, 0, n, l, r);
    }

    void add(int v, int l1, int r1, int l, int r, li x) {
        if (l >= r1 || l1 >= r) {
            return;
        }
        if (l <= l1 && r >= r1) {
            a[v] += x;
            to_add[v] += x;
            return;
        }
        relax(v);
        int m = (l1 + r1) / 2;
        add(v + v, l1, m, l, r, x);
        add(v + v + 1, m, r1, l, r, x);
        a[v] = max(a[v + v], a[v + v + 1]);
    }

    void add(int l, int r, li x) {
        add(1, 0, n, l, r, x);
    }

    void chg(int v, int l1, int r1, int pos, li x) {
        if (pos >= r1 || l1 > pos) {
            return;
        }
        if (pos == l1 && pos + 1 == r1) {
            a[v] = x;
            return;
        }
        relax(v);
        int m = (l1 + r1) / 2;
        chg(v + v, l1, m, pos, x);
        chg(v + v + 1, m, r1, pos, x);
        a[v] = max(a[v + v], a[v + v + 1]);
    }

    void chg(int pos, li x) {
        chg(1, 0, n, pos, x);
    }
};

struct Fenwick {
    int n;
    vector<li> a;

    Fenwick(int _n): n(_n), a(_n) {}

    void add(int pos, li x) {
        while (pos < n) {
            a[pos] += x;
            pos |= pos + 1;
        }
    }

    li get(int pos) {
        li res = 0;
        while (pos >= 0) {
            res += a[pos];
            pos = (pos & (pos + 1)) - 1;
        }
        return res;
    }
};

const int N = 1 << 20;
int d[N];

SegTree tree(N);
Fenwick p(N + 1);

li get(int t) {
    return max<li>(t, p.get(t) + tree.get(0, t + 1));
}

void add(int t, int new_d) {
    assert(d[t] == 0);
    d[t] = new_d;
    tree.add(t, N, -new_d);
    tree.chg(t, t - p.get(t));
    p.add(t, new_d);
}

void rem(int t) {
    assert(d[t] > 0);
    int old_d = d[t];
    d[t] = 0;
    tree.add(t, N, old_d);
    tree.chg(t, -inf);
    p.add(t, -old_d);
}

void solve(bool __attribute__((unused)) read) {
    int q;
    cin >> q;
    map<int, int> ts;
    int timer = 0;
    while (q--) {
        ++timer;
        char tp;
        cin >> tp;
        if (tp == '+') {
            int t, new_d;
            cin >> t >> new_d;
            add(t, new_d);
            ts[timer] = t;
        } else if (tp == '-') {
            int t;
            cin >> t;
            rem(ts[t]);
        } else if (tp == '?') {
            int t;
            cin >> t;
            cout << get(t) - t << "\n";
        } else {
            assert(false);
        }
    }
}