#define _CRT_SECURE_NO_WARNINGS
#define _USE_MATH_DEFINES
#include<algorithm>
#include<bitset>
#include<cassert>
#include<cmath>
#include<complex>
#include<cstdio>
#include<cstring>
#include<ctime>
#include<deque>
#include<functional>
#include<iomanip>
#include<iostream>
#include<map>
#include<queue>
#include<random>
#include<stack>
#include<set>
#include<string>
#include<unordered_map>
#include<unordered_set>
#include<vector>

using namespace std;

typedef long long lint;

#define For(i, n) for (int (i)= 0; (i) < (int)(n); (i)++)
#define sz(x) (int)(x).size()
#define all(v) (v).begin(), (v).end()

//#pragma comment(linker, "/STACK:16777216")

const int inf = (int)1e5;

struct Graph {
	vector<vector<int> > incident;
	vector<vector<int> > dist;
	int size;
	Graph(int new_size) {
		size = new_size;
		incident.resize(new_size);
	}
	void add_edge(int a, int b) {
		incident[a].push_back(b);
		incident[b].push_back(a);
	}
	void recalc_dist() {
		dist.resize(size);
		For(i, size) {
			dist[i].resize(size, inf);
		}
		For(i, size)
			dist[i][i] = 0;
		For(i, size) {
			for (auto u : incident[i]) {
				dist[i][u] = dist[u][i] = 1;
			}
		}
		For(k, size) For(i, size) For(j, size)
			dist[i][j] = min(dist[i][j], dist[i][k] + dist[k][j]);
	}
};

#ifdef LOCAL
#define INTERACTOR
#define VERBOSE
#endif

int secret_vertex = -1;
void init_interactor()
{
	++secret_vertex;
}

int ask(const Graph& g, int v)
{
	int res;
#ifdef INTERACTOR
	if (v == secret_vertex)
		res = -1;
	else
	{
		for (auto u : g.incident[v])
			if (g.dist[u][secret_vertex] < g.dist[v][secret_vertex])
				res = u;
	}
#ifdef VERBOSE
	cout << v + 1 << endl;
	if (res == -1)
		cout << "FOUND" << endl;
	else
		cout << "GO " << res + 1 << endl;
#endif
#else
	cout << v + 1 << endl;
	string s;
	cin >> s;
	if (s == "FOUND")
		res = -1;
	else
	{
		cin >> res;
		--res;
	}
#endif
	return res;
}

#ifdef LOCAL
//#define STRESS_GEN
#endif

void solve() {
	int n, m;
#ifdef STRESS_GEN
	n = 500;
	m = 1;
#else
	cin >> n >> m;
#endif
	Graph graph(n);
	For(i, m)
	{
		int k, prv;
#ifdef STRESS_GEN
		k = 501;
		prv = n;
#else
		cin >> k >> prv;
#endif
		--prv;
		For(i, k - 1)
		{
			int cur;
#ifdef STRESS_GEN
			cur = i + 1;
#else
			cin >> cur;
#endif
			--cur;
			graph.add_edge(prv, cur);
			prv = cur;
		}
	}
	graph.recalc_dist();
#ifdef INTERACTOR
#endif
	For(query, n)
	{
		init_interactor();
		vector<int> candidates;
		For(i, n)
			candidates.push_back(i);
		int question;
		for (question = 0; question < 10; ++question)
		{
			int best_val = inf, best;
			For(v, n)
			{
				int cur = 0;
				for (auto ans : graph.incident[v])
				{
					int cur_cur = 0;
					for (auto cand : candidates)
						if (graph.dist[ans][cand] < graph.dist[v][cand])
							cur_cur++;
					cur = max(cur, cur_cur);
				}
				if (cur < best_val)
				{
					best_val = cur;
					best = v;
				}
			}
			int ans = ask(graph, best);
			if (ans == -1)
				break;
			For(i, sz(candidates))
				if (!(graph.dist[ans][candidates[i]] < graph.dist[best][candidates[i]]))
				{
					swap(candidates[i], candidates[sz(candidates) - 1]);
					candidates.pop_back();
					i--;
				}
		}
		if (question == 10)
			throw;
	}
}

int main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
#ifdef LOCAL
	freopen("input.txt", "rt", stdin);
	freopen("output.txt", "wt", stdout);
#endif
	solve();
#ifdef LOCAL
	printf("\n\n%.3lf\n", (double)clock() / CLOCKS_PER_SEC);
#endif
}
