#include <algorithm>
#include <cmath>
#include <functional>
#include <iostream>
#include <map>
#include <queue>
#include <set>
#include <sstream>
#include <string>
#include <vector>

using namespace std;

using LL = long long;
using pii = pair<int, int>;

#define X first
#define Y second

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v) {
	return out << "(" << v.first << ", " << v.second << ")";
}

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v) {
	out << "{";
	bool f = false;
	for (const auto& p : v) {
		out << (!f ? "" : ", ") << p;
		f = true;
	}
	return out << "}";
}

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v) {
	out << "{";
	for (int i = 0; i < int(v.size()); ++i) {
		out << (i == 0 ? "" : ", ") << v[i];
	}
	return out << "}";
}

void cerr_printer(bool start) {}
template<typename T, typename ... Args>
void cerr_printer(bool start, const T& x, const Args& ... args) {
	if (!start) cerr << ", ";
	cerr << x;
	cerr_printer(false, args...);
}

template<typename ... Args>
void dbg(const char * name, int line, const Args& ... args) {
	cerr << "[" << line << "] (" << name << ") = (";
	cerr_printer(true, args...);
	cerr << ")" << endl;
}

#define DBG(...) {dbg(#__VA_ARGS__, __LINE__, __VA_ARGS__); }

const int M = 6;
const int M_WE = 4;
const int N = 204;        // <<<<<<<

const int WIN_CNT = 25;      // <<<<<
const int LST_MT = 5;
const int LST_WIN_CNT = 15; // <<<<<<

bool dp[M][M_WE][N][N];
pii lst[M][M_WE][N][N];

struct Solver {
	static void initDp() {
		for (int mt = 0; mt < M; ++mt) {
			for (int wwin = 0; wwin < M_WE; ++wwin) {
				for (int we = 0; we < N; ++we) {
					fill(dp[mt][wwin][we], dp[mt][wwin][we] + N, false);
				}
			}
		}

		dp[0][0][0][0] = true;
		for (int mt = 1; mt < M; ++mt) {
			for (int wwin = 0; wwin < M_WE; ++wwin) {
				if (mt - wwin > 3) {
					continue;
				}

				for (int we = 0; we < N; ++we) {
					for (int they = 0; they < N; ++they) {
						for (int wwn = 0; wwn < 2; ++wwn) {
							if (wwn && wwin == 0) {
								continue;
							}

							const int pwwin = wwin - wwn;
							const int cur_win = (LST_MT == mt) ? LST_WIN_CNT : WIN_CNT;

							for (int un = 0; un < cur_win - 2; ++un) {
								const int cwin = cur_win;
								const int pwe = wwn ? (we - cwin) : (we - un);
								const int pthey = wwn ? (they - un) : (they - cwin);
								if (pwe < 0 || pthey < 0) break;

								if (mt - 1 - pwwin < 3 && pwwin < 3 && dp[mt - 1][pwwin][pwe][pthey]) {
									// cerr << mt << " " << wwin << " " << we << " " << they << endl;
									dp[mt][wwin][we][they] = true;
									lst[mt][wwin][we][they] = pii(wwn ? cwin : un, wwn ? un : cwin);
									break;
								}
							}

							if (dp[mt][wwin][we][they]) {
								break;
							}

							for (int cwin = cur_win; cwin < N; ++cwin) {
								const int un = cwin - 2;
								const int pwe = wwn ? (we - cwin) : (we - un);
								const int pthey = wwn ? (they - un) : (they - cwin);
								if (pwe < 0 || pthey < 0) break;

								if (mt - 1 - pwwin < 3 && pwwin < 3 && dp[mt - 1][pwwin][pwe][pthey]) {
									dp[mt][wwin][we][they] = true;
									lst[mt][wwin][we][they] = pii(wwn ? cwin : un, wwn ? un : cwin);
									break;
								}
							}

							if (dp[mt][wwin][we][they]) {
								break;
							}
						}
					}
				}
			}
		}
	}

	vector<pii> make_answer(int mt, int we_win, int a, int b) {
		if (mt == 0) return vector<pii>();
		if (!dp[mt][we_win][a][b]) {
			cerr << mt << " " << we_win << " " << a << " " << b << endl;
			return vector<pii>();
		}
		pii cr = lst[mt][we_win][a][b];
		if (cr.X >= cr.Y + 2) --we_win;
		vector<pii> res = make_answer(mt - 1, we_win, a - cr.X, b - cr.Y);
		res.push_back(cr);

		return res;
	}

	vector<pii> refresh_answer(vector<pii> v) {
		if (v.size() < 5) {
			int win = 0;
			for (pii p : v) if (p.X >= p.Y + 2) ++win;
			if (win == 3) {
				sort(v.rbegin(), v.rend(), [](pii a, pii b) { return (a.X - a.Y) > (b.X - b.Y); });
			} else {
				sort(v.begin(), v.end(), [](pii a, pii b) { return (a.X - a.Y) > (b.X - b.Y); });
			}

			return v;
		}

		return v;
	}

	void solve(istream& cin, ostream& cout) {
		int a, b;
		cin >> a >> b;

		int res = -1000;
		int w = -1;
		int t = -1;

		vector<pii> cur;

		for (int we_win = 0; we_win <= 3; ++we_win) {
			for (int they_win = 0; they_win <= 3; ++they_win) {
				if (we_win + they_win > 5) continue;
				if (we_win == 3 || they_win == 3) {
					if (dp[we_win + they_win][we_win][a][b]) {
						if (res < we_win - they_win) {
							res = max(res, we_win - they_win);
							w = we_win;
							t = they_win;
							cur = make_answer(we_win + they_win, we_win, a, b);
						}
					}
				} else if (we_win + they_win == 5) {
					if (dp[we_win + they_win][we_win][a][b]) {
						if (res < we_win - they_win) {
							res = max(res, we_win - they_win);
							w = we_win;
							t = they_win;
							cur = make_answer(we_win + they_win, we_win, a, b);
						}
					}
				}
			}
		}

		if (res == -1000) {
			cout << "Impossible" << endl;
			return;
		}

		cur = refresh_answer(cur);
		cout << w << ":" << t << endl;
		for (pii p : cur) cout << p.X << ":" << p.Y << " ";
		cout << endl;

	}
};

struct Brute {
	void solve(istream& cin, ostream& cout) {
	}
};

int main() {
	Solver::initDp();

	int t;
	cin >> t;
	for (int i = 0; i < t; ++i)
		Solver().solve(cin, cout);
}