#include <algorithm>
#include <cmath>
#include <functional>
#include <iostream>
#include <map>
#include <queue>
#include <set>
#include <sstream>
#include <string>
#include <vector>

using namespace std;

using LL = long long;
using pii = pair<int, int>;
using pll = pair<LL, LL>;

#define X first
#define Y second

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v) {
	return out << "(" << v.first << ", " << v.second << ")";
}

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v) {
	out << "{";
	bool f = false;
	for (const auto& p : v) {
		out << (!f ? "" : ", ") << p;
		f = true;
	}
	return out << "}";
}

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v) {
	out << "{";
	for (int i = 0; i < int(v.size()); ++i) {
		out << (i == 0 ? "" : ", ") << v[i];
	}
	return out << "}";
}

void cerr_printer(bool start) {}
template<typename T, typename ... Args>
void cerr_printer(bool start, const T& x, const Args& ... args) {
	if (!start) cerr << ", ";
	cerr << x;
	cerr_printer(false, args...);
}

template<typename ... Args>
void dbg(const char * name, int line, const Args& ... args) {
	cerr << "[" << line << "] (" << name << ") = (";
	cerr_printer(true, args...);
	cerr << ")" << endl;
}

#define DBG(...) {dbg(#__VA_ARGS__, __LINE__, __VA_ARGS__); }

struct Solver {
	LL egcd(LL a, LL b, LL& x, LL& y) {
		if (a > b) {
			return egcd(b, a, y, x);
		}

		if (a == 0) {
			x = 0;
			y = 1;
			return b;
		}

		LL res = egcd(b % a, a, y, x);
		LL d = (b / a) * y;
		x -= d;
		return res;
	}

	pll get(int n) {
		for (int i = 2; i * i <= n; ++i) {
			if (n % i == 0) {
				LL x = 1;
				LL y = n;
				while (y % i == 0) {
					x *= i;
					y /= i;
				}

				if (y == 1) return pll(1, 1);
				return pll(x, y);
			}
		}

		return pll(1, 1);
	}

	void solve(istream& cin, ostream& cout) {
		LL n;
		cin >> n;

		pll p = get(n);
		if (p == pll(1, 1)) {
			cout << "NO" << endl;
			return;
		}

		LL x, y;
		egcd(p.X, p.Y, x, y);

		x *= (n - 1);
		y *= (n - 1);

		if (x < 0) {
			LL t = (-x + p.Y - 1) / p.Y;
			x += t * p.Y;
			y -= t * p.X;
		}

		swap(x, y);
		swap(p.X, p.Y);

		if (x < 0) {
			LL t = (-x + p.Y - 1) / p.Y;
			x += t * p.Y;
			y -= t * p.X;
		}

		cout << "YES" << endl;
		cout << 2 << endl;
		cout << x << " " << p.Y << endl;
		cout << y << " " << p.X << endl;
	}
};

struct Brute {
	void solve(istream& cin, ostream& cout) {
	}
};

int main() {
	Solver().solve(cin, cout);
}