#include <algorithm>
#include <cmath>
#include <functional>
#include <iostream>
#include <map>
#include <queue>
#include <set>
#include <sstream>
#include <string>
#include <vector>
#include <cstring>
#include <cstdlib>

using namespace std;

using LL = long long;
using pii = pair<int, int>;

#define X first
#define Y second

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v) {
	return out << "(" << v.first << ", " << v.second << ")";
}

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v) {
	out << "{";
	bool f = false;
	for (const auto& p : v) {
		out << (!f ? "" : ", ") << p;
		f = true;
	}
	return out << "}";
}

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v) {
	out << "{";
	for (int i = 0; i < int(v.size()); ++i) {
		out << (i == 0 ? "" : ", ") << v[i];
	}
	return out << "}";
}

void cerr_printer(bool start) {}
template<typename T, typename ... Args>
void cerr_printer(bool start, const T& x, const Args& ... args) {
	if (!start) cerr << ", ";
	cerr << x;
	cerr_printer(false, args...);
}

template<typename ... Args>
void dbg(const char * name, int line, const Args& ... args) {
	cerr << "[" << line << "] (" << name << ") = (";
	cerr_printer(true, args...);
	cerr << ")" << endl;
}

#define DBG(...) {dbg(#__VA_ARGS__, __LINE__, __VA_ARGS__); }

struct Solver {
	struct Token {
		string type;
		string val;
		bool is_repl = false;
	};

	vector<string> forb;
	bool word_symbol(char c) {
		if (isalnum(c))
			return true;
		if (c == '_' || c == '$')
			return true;
		return false;
	}

	bool has_path(string s) {
		for (auto it : forb) {
			if (it.find(s) == 0)
				return true;
		}
		return false;
	}

	vector<Token> parse_tokens(string source) {
		bool is_num = true;
		bool is_comm = true;
		bool is_word = true;

		string cur_token = "";
		vector<Token> tokens;

		for (int pos = 0; pos < source.size(); ++pos) {
			char c = source[pos];

			string type = "";
			if (!word_symbol(c) && is_word) {
				is_word = false;
				type = "word";
			}
			if (!isdigit(c) && is_num) {
				is_num = false;
				type = "num";
			}
			if (is_comm && !has_path(cur_token + c)) {
				is_comm = false;
				type = "comm";
			}

			if (!is_num && !is_word && !is_comm && cur_token.size() > 0) {
				tokens.push_back({ type, cur_token });
				cur_token = "";
				pos--;
				is_num = true;
				is_comm = true;
				is_word = true;
			} else if (c == ' ') {
				is_num = true;
				is_comm = true;
				is_word = true;
				continue;
			} else {
				cur_token += c;
			}
		}

		if (cur_token.size()) {
			string type = "";
			if (is_comm) {
				type = "comm";
			} else if (is_num) {
				type = "num";
			} else {
				type = "word";
			}

			tokens.push_back({ type, cur_token });
		}
		return tokens;
	}

	void replace_tokens(vector<Token>& tokens) {
		vector<string> repl;
		vector<string> last = { "" };
		for (int i = 0; i < 3; ++i) {
			vector<string> cur;
			for (auto it : last) {
				for (char c = 'a'; c <= 'z'; ++c) {
					bool bad = false;
					for (auto it2 : forb) {
						if (it2 == (it + c)) {
							bad = true;
							break;
						}
					}
					if (!bad) {
						repl.push_back(it + c);
						cur.push_back(it + c);
					}
				}
			}
			last = cur;
		}

		int repl_pos = 0;

		for (int i = 0; i < tokens.size(); ++i) {
			if (tokens[i].type == "word" && !tokens[i].is_repl) {
				string val = tokens[i].val;
				for (int j = i; j < tokens.size(); ++j) {
					if (tokens[j].type == "word" && tokens[j].val == val) {
						tokens[j].val = repl[repl_pos];
						tokens[j].is_repl = true;
					}
				}
				repl_pos++;
			}
		}
	}

	void solve(istream& cin, ostream& cout) {
		int n;
		cin >> n;

		string source = "";
		forb.resize(n);
		for (auto& it : forb) {
			cin >> it;
		}

		int m;
		cin >> m;
		string t;
		getline(cin, t);

		for (int i = 0; i < m; ++i) {
			getline(cin, t);

			int pos = t.find('#');

			if (pos != string::npos) {
				t = t.substr(0, pos);
			}
			source += t;
			source += ' ';
		}
		vector<Token> tokens = parse_tokens(source);
		replace_tokens(tokens);


		string res = "";

		//for (int i = 0; i < tokens.size(); ++i) {
		//	bool need_space = false;
		//	vector<Token> tokens2 = parse_tokens(res + tokens[i].val);

		//	need_space = tokens2.size() != i + 1;
		//	for (int j = 0; j < i + 1 && !need_space; ++j) {
		//		if (tokens2[j].type != tokens[j].type) {
		//			need_space = true;
		//			// cerr << tokens2[j].type << " " << tokens[j].type << endl;
		//		}

		//		if (tokens2[j].val != tokens[j].val) {
		//			need_space = true;
		//			// cerr << tokens2[j].val << " " << tokens[j].val << endl;
		//		}
		//	}

		//	if (need_space)
		//		res += ' ';
		//	res += tokens[i].val;
		//}

		for (int i = 0; i < tokens.size(); ++i) {
			bool need_space = false;
			if (i > 0 &&
				((tokens[i].type == "word" && tokens[i - 1].type == "word") ||
				(tokens[i].type == "word" && tokens[i - 1].type == "comm" && word_symbol(res.back())) ||
				(tokens[i].type == "comm" && word_symbol(res.back()) && word_symbol(tokens[i].val[0])) ||
				(tokens[i].type == "num" && isdigit(res.back())) ||
				(tokens[i].type == "num" && tokens[i - 1].type == "word"))) {
				need_space = true;
			}
			if (i > 0 && (tokens[i].type == "comm")) {
				string check = tokens[i].val;
				for (int j = res.size() - 1; j >= 0 && check.size() < 20; j--) {
					check.insert(check.begin(), res[j]);
					bool bad = false;
					for (auto it : forb) {
						if (it != tokens[i-1].val && it.find(check) == 0) {
							bad = true;
							break;
						}
					}
					if (bad) {
						need_space = true;
						break;
					}
				}
			}

			if (need_space)
				res += ' ';
			res += tokens[i].val;
		}

		cout << res << endl;
	}
};

struct Brute {
	void solve(istream& cin, ostream& cout) {
	}
};

int main() {
	// freopen("input.txt", "r", stdin);
	Solver().solve(cin, cout);
}