#include <algorithm>
#include <cmath>
#include <functional>
#include <iostream>
#include <map>
#include <queue>
#include <set>
#include <sstream>
#include <string>
#include <vector>
#include <cstring>
#include <cstdlib>

using namespace std;

using LL = long long;
using pii = pair<int, int>;

#define X first
#define Y second

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v);

template<typename U, typename T>
ostream& operator<<(ostream& out, const pair<U, T>& v) {
	return out << "(" << v.first << ", " << v.second << ")";
}

template<typename U, typename T>
ostream& operator<<(ostream& out, const map<U, T>& v) {
	out << "{";
	bool f = false;
	for (const auto& p : v) {
		out << (!f ? "" : ", ") << p;
		f = true;
	}
	return out << "}";
}

template<typename T>
ostream& operator<<(ostream& out, const vector<T>& v) {
	out << "{";
	for (int i = 0; i < int(v.size()); ++i) {
		out << (i == 0 ? "" : ", ") << v[i];
	}
	return out << "}";
}

void cerr_printer(bool start) {}
template<typename T, typename ... Args>
void cerr_printer(bool start, const T& x, const Args& ... args) {
	if (!start) cerr << ", ";
	cerr << x;
	cerr_printer(false, args...);
}

template<typename ... Args>
void dbg(const char * name, int line, const Args& ... args) {
	cerr << "[" << line << "] (" << name << ") = (";
	cerr_printer(true, args...);
	cerr << ")" << endl;
}

#define DBG(...) {dbg(#__VA_ARGS__, __LINE__, __VA_ARGS__); }

struct Solver {
	struct Coord {
		int x, y, z;
		Coord(int x, int y, int z) : x(x), y(y), z(z) {}

		bool operator<(const Coord& o) const {
			return make_pair(make_pair(x, y), z) <
				make_pair(make_pair(o.x, o.y), o.z);
		}
	};

	void print_answer(const set<Coord>& mp, const vector<Coord>& pts) {
		pii xx(1e9, -1e9), yy(1e9, -1e9), zz(1e9, -1e9);
		for (Coord c : mp) {
			xx = pii(min(xx.X, c.x), max(xx.Y, c.x));
			yy = pii(min(yy.X, c.y), max(yy.Y, c.y));
			zz = pii(min(zz.X, c.z), max(zz.Y, c.z));
		}

		for (Coord c : pts) {
			xx = pii(min(xx.X, c.x), max(xx.Y, c.x));
			yy = pii(min(yy.X, c.y), max(yy.Y, c.y));
			zz = pii(min(zz.X, c.z), max(zz.Y, c.z));
		}

		xx.X -= 2;
		xx.Y += 2;

		yy.X -= 2;
		yy.Y += 2;

		zz.X -= 2;
		zz.Y += 2;

		int xs = xx.Y - xx.X + 1;
		int ys = yy.Y - yy.X + 1;
		int zs = zz.Y - zz.X + 1;

		cout << ys << " " << xs << " " << zs << endl;

		vector<string> field(xs, string(ys, '.'));
		for (int z = zs - 1; z >= 0; --z) {
			for (int x = 0; x < xs; ++x) {
				for (int y = 0; y < ys; ++y) {
					if (mp.count(Coord(x + xx.X, y + yy.X, z + zz.X))) field[x][y] = '#';
					else field[x][y] = '.';
				}
			}

			for (int i = 0; i < pts.size(); ++i) {
				if (pts[i].z == z + zz.X) {
					field[pts[i].x - xx.X][pts[i].y - yy.X] = '1' + i;
				}
			}

			for (const string& s : field) cout << s << endl;
			cout << endl;
		}
	}

	void fill(set<Coord>& st, int z, int xl, int xr, int yl, int yr) {
		if (xl > xr) swap(xl, xr);
		if (yl > yr) swap(yl, yr);

		for (int x = xl; x <= xr; ++x) {
			for (int y = yl; y <= yr; ++y) {
				st.insert(Coord(x, y, z));
			}
		}
	}

	void unfill(set<Coord>& st, int z, int xl, int xr, int yl, int yr) {
		if (xl > xr) swap(xl, xr);
		if (yl > yr) swap(yl, yr);

		++xl; --xr;
		++yl; --yr;

		for (int x = xl; x <= xr; ++x) {
			for (int y = yl; y <= yr; ++y) {
				st.erase(Coord(x, y, z));
			}
		}
	}

	void solve(istream& cin, ostream& cout) {
		int n;
		cin >> n;
		vector<vector<int>> a(n, vector<int>(n));
		for (int i = 0; i < n; ++i) {
			for (int j = 0; j < n; ++j)
				cin >> a[i][j];
		}

		set<Coord> mp;

		const int T = 40;
		const int R = 40;
		
		for (int i = 0; i < n; ++i) {
			// Make lader
			{
				const int lvl = 3 * i;
				for (int xx = 0; xx <= T; ++xx) {
					int z = min(xx, lvl);
					mp.insert(Coord(-xx, 2 * i, z));
				}
			}

			{
				const int lvl = 3 * i;
				for (int dl = 0; dl < 3; ++dl) {
					fill(mp, lvl + dl, -(T + 1), -(T + 3), 0, R);
					fill(mp, lvl + dl, 1, 3, 0, R);
					fill(mp, lvl + dl, -(T + 3), 3, -1, -3);
				}

				unfill(mp, lvl + 1, -(T + 1), -(T + 3), -3, R);
				unfill(mp, lvl + 1, 1, 3, -3, R);
				unfill(mp, lvl + 1, -(T + 3), 3, -1, -3);

				mp.erase(Coord(-T - 1, 2 * i, lvl + 1));
			}

			{
				for (int i = 0; i < n; ++i) {
					for (int j = 0; j < n; ++j) {
						if (a[i][j] == 1) {
							mp.erase(Coord(1, 2 * j, 3 * i + 1));
						}
					}
				}
			}
		}
		
		vector<Coord> cr;
		for (int i = 0; i < n; ++i) {
			cr.push_back(Coord(0, 2 * i, 1));
		}
		print_answer(mp, cr);
	}
};

struct Brute {
	void solve(istream& cin, ostream& cout) {
	}
};

int main() {
	// freopen("input.txt", "r", stdin);
	Solver().solve(cin, cout);
}