#pragma comment(linker, "/STACK:134217728")
#define _CRT_SECURE_NO_WARNINGS
#define _USE_MATH_DEFINES

#include <algorithm>
#include <bitset>
#include <cassert>
#include <cmath>
#include <complex>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <ctime>
#include <deque>
#include <functional>
#include <iomanip>
#include <iostream>
#include <map>
#include <queue>
#include <random>
#include <set>
#include <stack>
#include <string>
#include <unordered_map>
#include <unordered_set>
#include <vector>
using namespace std;

typedef long long ll;
typedef unsigned char uch;

const int MaxScore = 205;
const int INF = (int)1e5;

struct Tour
{
	int fst, snd;
};

vector<Tour> BuildGame(int a, int b, int t1, int t2, int t3, int t4, 
	int f1, int f2, int f3, int f4, int overflow, int a_left, int b_left)
{
	a -= overflow;
	b -= overflow;
	a_left -= overflow;
	b_left -= overflow;

	vector<Tour> tours;
	for (int i = 0; i < t1; i++)
	{
		tours.push_back(Tour{ 25, min(b_left, 23) });
		b_left -= min(b_left, 23);
	}
	for (int i = 0; i < t2; i++)
	{
		tours.push_back(Tour{ 26 + overflow, 24 + overflow });
		overflow = 0;
	}
	for (int i = 0; i < t3; i++)
	{
		tours.push_back(Tour{ min(a_left, 23), 25 });
		a_left -= min(a_left, 23);
	}
	for (int i = 0; i < t4; i++)
	{
		tours.push_back(Tour{ 24 + overflow, 26 + overflow });
		overflow = 0;
	}


	for (int i = 0; i < f1; i++)
	{
		tours.push_back(Tour{ 15, min(b_left, 13) });
		b_left -= min(b_left, 13);
	}
	for (int i = 0; i < f2; i++)
	{
		tours.push_back(Tour{ 16 + overflow, 14 + overflow });
		overflow = 0;
	}
	for (int i = 0; i < f3; i++)
	{
		tours.push_back(Tour{ min(a_left, 13), 15 });
		a_left -= min(a_left, 13);
	}
	for (int i = 0; i < f4; i++)
	{
		tours.push_back(Tour{ 14 + overflow, 16 + overflow });
		overflow = 0;
	}

	return tours;
}

void PrintGame(const vector<Tour>& game)
{
	int a_win = 0;
	int b_win = 0;
	for (const auto& item : game)
	{
		if (item.fst > item.snd)
		{
			a_win++;
		}
		else
		{
			b_win++;
		}
	}

	cout << a_win << ":" << b_win << "\n";
	for (const auto& item : game)
	{
		cout << item.fst << ":" << item.snd << " ";
	}
	cout << "\n";
}

bool TrySolve(int a, int b, int t1, int t2, int t3, int t4, int f1, int f2, int f3, int f4)
{
	auto old_a = a;
	auto old_b = b;

	a -= t1 * 25;
	b -= t3 * 25;

	a -= t2 * 26;
	b -= t2 * 24;

	a -= t4 * 24;
	b -= t4 * 26;


	a -= f1 * 15;
	b -= f3 * 15;

	a -= f2 * 16;
	b -= f2 * 14;

	a -= f4 * 14;
	b -= f4 * 16;

	if (a < 0 || b < 0)
	{
		return false;
	}

	auto overflow = max(a - t3 * 23 - f3 * 13, b - t1 * 23 - f1 * 13);

	if (overflow <= 0 || t2 > 0 || t4 > 0)
	{
		auto game = BuildGame(old_a, old_b, t1, t2, t3, t4, f1, f2, f3, f4, max(0, overflow), a, b);
		PrintGame(game);
		return true;
	}
	return false;
}

struct AAA
{
	int t1, t2, t3, t4, f1, f2, f3, f4;
};

void Brute(int a, int b)
{
	vector<AAA> v;
	for (int t1 = 5; t1 >= 0; t1--)
	{
		for (int t2 = 5; t2 >= 0; t2--)
		{
			for (int t3 = 0; t3 < 5; t3++)
			{
				for (int t4 = 0; t4 < 5; t4++)
				{
					for (int f1 = 1; f1 >= 0; f1--)
					{
						for (int f2 = 1; f2 >= 0; f2--)
						{
							for (int f3 = 0; f3 < 2; f3++)
							{
								for (int f4 = 0; f4 < 2; f4++)
								{
									v.push_back(AAA{ t1, t2, t3, t4, f1, f2, f3, f4 });
								}
							}
						}
					}
				}
			}
		}
	}

	sort(v.begin(), v.end(), [](AAA a, AAA b) {
		int a_diff = a.t1 + a.t2 + a.f1 + a.f2 - (a.t3 + a.t4 + a.f3 + a.f4);
		int b_diff = b.t1 + b.t2 + b.f1 + b.f2 - (b.t3 + b.t4 + b.f3 + b.f4);
		return a_diff > b_diff;
	});

	for (auto const& vect : v)
	{
		auto t1 = vect.t1;
		auto t2 = vect.t2;
		auto t3 = vect.t3;
		auto t4 = vect.t4;
		auto f1 = vect.f1;
		auto f2 = vect.f2;
		auto f3 = vect.f3;
		auto f4 = vect.f4;
		if (f1 + f2 + f3 + f4 > 1)
		{
			continue;
		}
		if (t1 + t2 + t3 + t4 + f1 + f2 + f3 + f4 > 5)
		{
			continue;
		}
		if (t1 + t2 + t3 + t4 > 4)
		{
			continue;
		}
		if (t1 + t2 + f1 + f2 > 3 || t3 + t4 + f3 + f4 > 3)
		{
			continue;
		}
		if (TrySolve(a, b, t1, t2, t3, t4, f1, f2, f3, f4))
		{
			return;
		}
	}

	cout << "Impossible\n";
}

void Solve()
{
	int n;
	cin >> n;
	for (int i = 0; i < n; i++)
	{
		int a, b;
		cin >> a >> b;
		Brute(a, b);
	}
}

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	Solve();
	return 0;
}