import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.*;

public class Main {
    FastInput in;
    PrintWriter out;

    class Solver {
        int maxn = 200;
        Pair[] matches1;
        Pair[] matches2;
        Pair[][][][] parent = new Pair[maxn + 1][maxn + 1][4][4];

        void initMatches() {
            matches1 = new Pair[199 * 2];
            matches2 = new Pair[199 * 2];
            for (int i = 0; i <= 198; i++) {
                int j1 = Math.max(25, i + 2);
                matches1[i * 2] = new Pair(i, j1);
                matches1[i * 2 + 1] = new Pair(j1, i);

                int j2 = Math.max(15, i + 2);
                matches2[i * 2] = new Pair(i, j2);
                matches2[i * 2 + 1] = new Pair(j2, i);
            }
        }

        void initDp() {
            Queue<int[]> q = new ArrayDeque<>();
            q.add(new int[]{0, 0, 0, 0});
            while (!q.isEmpty()) {
                int[] cur = q.poll();
                int scoreA = cur[0];
                int scoreB = cur[1];
                int wonA = cur[2];
                int wonB = cur[3];
                for (Pair match : (wonA + wonB < 4 ? matches1 : matches2)) {
                    int willScoreA = scoreA + match.first;
                    int willScoreB = scoreB + match.second;
                    int willWonA = wonA + (match.first > match.second ? 1 : 0);
                    int willWonB = wonB + (match.first < match.second ? 1 : 0);
                    if (willScoreA > 200 || willScoreB > 200)
                        continue;
                    if (parent[willScoreA][willScoreB][willWonA][willWonB] != null)
                        continue;
                    parent[willScoreA][willScoreB][willWonA][willWonB] = match;
                    if (Math.max(willWonA, willWonB) < 3)
                        q.add(new int[]{willScoreA, willScoreB, willWonA, willWonB});
                }
            }
        }

        Pair fullScore;
        List<Pair> restore(int sumA, int sumB) {
            int startWinA = -1;
            int startWinB = -1;
            int startScore = 0;
            for (int winA = 0; winA <= 3; winA++) {
                for (int winB = 0; winB <= 3; winB++) {
                    if (winA < 3 && winB < 3) continue;
                    if (parent[sumA][sumB][winA][winB] != null && (startWinA == -1 || startScore < winA - winB)) {
                        startWinA = winA;
                        startWinB = winB;
                        startScore = winA - winB;
                    }
                }
            }
            if (startWinA == -1) return null;
            fullScore = new Pair(startWinA, startWinB);
            List<Pair> answer = new ArrayList<>();
            while (sumA > 0 || sumB > 0) {
                Pair p = parent[sumA][sumB][startWinA][startWinB];
                answer.add(p);
                sumA -= p.first;
                sumB -= p.second;
                if (p.first > p.second) startWinA--;
                if (p.first < p.second) startWinB--;
            }
            Collections.reverse(answer);
            return answer;
        }

        void solve() {
            initMatches();
            initDp();

            int q = in.readInt();
            while (q-- > 0) {
                int sumA = in.readInt();
                int sumB = in.readInt();
                List<Pair> ans = restore(sumA, sumB);
                if (ans == null) {
                    out.println("Impossible");
                    continue;
                }
                out.println(fullScore);
                for (Pair p : ans) {
                    out.print(p + " ");
                }
                out.println();
            }
        }
    }

    class Pair implements Comparable<Pair> {
        int first, second;

        Pair(int first, int second) {
            this.first = first;
            this.second = second;
        }

        @Override
        public int compareTo(Pair o) {
            int c = Integer.compare(first, o.first);
            if (c == 0) c = Integer.compare(second, o.second);
            return c;
        }

        @Override
        public String toString() {
            return first + ":" + second;
        }
    }

    void run() {
        in = new FastInput();
        out = new PrintWriter(System.out);
        new Solver().solve();
        out.close();
    }

    public static void main(String[] args) {
        new Main().run();
    }

    class FastInput {
        BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
        StringTokenizer st = new StringTokenizer("");

        String next() {
            try {
                while (!st.hasMoreTokens()) {
                    st = new StringTokenizer(br.readLine());
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
            return st.nextToken();
        }

        int readInt() {
            return Integer.parseInt(next());
        }
    }
}
