import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.*;

public class Main {
    FastInput in;
    PrintWriter out;

    class Solver {

        void solve() {
            n = in.readInt();
            g = new List[n];
            gr = new List[n];
            for (int i = 0; i < n; i++) {
                g[i] = new ArrayList<>();
                gr[i] = new ArrayList<>();
            }
            for (int i = 0; i < n; i++) {
                g[i] = new ArrayList<>();
                for (int j = 0; j < n; j++) {
                    if (in.readInt() == 1) {
                        g[i].add(j);
                        gr[j].add(i);
                    }
                }
            }
            find();
            levelCols = Math.max(3 * edges.size(), n);
            out.printf("%d %d %d\n", levelCols, 3, newGraph.length * 2);
            for (int lvl : topSortOrder) {
                buildLevel(lvl);
                printLevel(fly);
                printLevel(ground);
            }
        }

        void printLevel(char[][] level) {
            for (char[] row : level)
                out.println(row);
            out.println();
        }

        List<Pair> edges;
        char[][] ground;
        char[][] fly;
        int levelCols;
        void buildLevel(int lvl) {
            int rows = 3;
            int cols = levelCols;
            ground = new char[rows][cols];
            fly = new char[rows][cols];
            for (int i = 0; i < rows; i++) Arrays.fill(ground[i], '#');
            for (int i = 0; i < rows; i++) Arrays.fill(fly[i], '.');
            for (int v : components.get(lvl)) fly[2][v] = (char) (v + '1');

            for (int i = 0; i < edges.size(); i++) {
                Pair e = edges.get(i);
                if (e.first == lvl) {
                    ground[0][1 + i * 3] = '.';
                } else if (e.second == lvl) {
                    ground[0][1 + i * 3] = '#';
                } else {
                    ground[0][1 + i * 3] = '.';
                    fly[0][1 + i * 3 - 1] = '#';
                    fly[0][1 + i * 3 + 1] = '#';
                    for (int j = 0; j < 3; j++)
                        fly[1][i * 3 + j] = '#';
                }
            }
        }

        int n;
        List<Integer>[] g;
        List<Integer>[] gr;

        boolean[] used;
        List<Integer> order;
        void dfs1(int v) {
            used[v] = true;
            for (int to : g[v])
                if (!used[to])
                    dfs1(to);
            order.add(v);
        }

        List<Integer> component;
        void dfs2(int v) {
            used[v] = true;
            component.add(v);
            for (int to : gr[v])
                if (!used[to])
                    dfs2(to);
        }

        int[] vertexToComponent;
        List<List<Integer>> components;
        void find() {
            used = new boolean[n];
            order = new ArrayList<>();
            for (int i = 0; i < n; i++) {
                if (!used[i]) {
                    dfs1(i);
                }
            }
            Arrays.fill(used, false);
            component = new ArrayList<>();
            components = new ArrayList<>();
            vertexToComponent = new int[n];
            for (int i = 0, j = 0; i < n; i++) {
                if (!used[i]) {
                    dfs2(i);
                    components.add(new ArrayList<>(component));
                    for (int v : component) vertexToComponent[v] = j;
                    component.clear();
                    j++;
                }
            }
            int componentCount = components.size();
            newGraph = new Set[componentCount];
            for (int i = 0; i < componentCount; i++)
                newGraph[i] = new HashSet<>();
            for (int i = 0; i < n; i++)
                for (int to : g[i])
                    if (vertexToComponent[i] != vertexToComponent[to])
                        newGraph[vertexToComponent[i]].add(vertexToComponent[to]);

            topSort();
            newGraph2 = new int[componentCount][componentCount];
            edges = new ArrayList<>();
            for (int i = 0; i < componentCount; i++) {
                for (int to : newGraph[i]) {
                    newGraph2[i][to] = 1;
                    newGraph2[to][i] = -1;
                    edges.add(new Pair(i, to));
                }
            }
        }

        int[][] newGraph2;
        Set<Integer>[] newGraph;
        int[] topSortOrder;
        int[] indexInTopSort;
        void topSort() {
            int n = newGraph.length;
            int[] indeg = new int[n];
            for (int i = 0; i < n; i++)
                for (int to : newGraph[i])
                    indeg[to]++;
            Queue<Integer> q = new ArrayDeque<>();
            for (int i = 0; i < n; i++)
                if (indeg[i] == 0)
                    q.add(i);
            topSortOrder = new int[n];
            indexInTopSort = new int[n];
            int at = 0;
            while (!q.isEmpty()) {
                int v = q.poll();
                topSortOrder[at] = v;
                indexInTopSort[v] = at;
                at++;
                for (int to : newGraph[v]) {
                    if (--indeg[to] == 0) {
                        q.add(to);
                    }
                }
            }
        }
    }

    class Pair implements Comparable<Pair> {
        int first, second;

        Pair(int first, int second) {
            this.first = first;
            this.second = second;
        }

        @Override
        public int compareTo(Pair o) {
            int c = Integer.compare(first, o.first);
            if (c == 0) c = Integer.compare(second, o.second);
            return c;
        }

        @Override
        public String toString() {
            return first + ":" + second;
        }
    }

    void run() {
        in = new FastInput();
        out = new PrintWriter(System.out);
        new Solver().solve();
        out.close();
    }

    public static void main(String[] args) {
        new Main().run();
    }

    class FastInput {
        BufferedReader br = new BufferedReader(new InputStreamReader(System.in));
        StringTokenizer st = new StringTokenizer("");

        String next() {
            try {
                while (!st.hasMoreTokens()) {
                    st = new StringTokenizer(br.readLine());
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
            return st.nextToken();
        }

        int readInt() {
            return Integer.parseInt(next());
        }
    }
}
