#define _CRT_SECURE_NO_DEPRECATE
#include <iostream>
#include <algorithm>
#include <vector>
#include <cstdlib>
#include <cassert>
#include <map>
#include <set>
using namespace std;

const int N = 4*3 * 100000 + 5;

int n;
int ti[N];
int dur[N];

////////////////////////////////////
struct SegmentTree {
	long long initVal[4 * N];
	long long addTree[4 * N];
	long long sumTree[4 * N];

	void pull(int v) {
		sumTree[v] = sumTree[v + v] + sumTree[v + v + 1];
	}

	void push(int v, int tl, int tr) {
		int tm = (tl + tr) / 2;
		long long addVal = addTree[v];
		addTree[v + v] += addVal;
		addTree[v + v + 1] += addVal;

		sumTree[v + v] += addVal * (tm - tl + 1);
		sumTree[v + v + 1] += addVal * (tr - (tm + 1) + 1);

		addTree[v] = 0;
	}

	void build(int v, int tl, int tr) {
		if (tl == tr) {
			sumTree[v] = initVal[tl];
			return;
		}
		int tm = (tl + tr) / 2;
		build(v + v, tl, tm);
		build(v + v + 1, tm + 1, tr);
		pull(v);
	}

	void add(int v, int tl, int tr, int l, int r, long long addVal) {
		if (l <= tl && tr <= r) {
			addTree[v] += addVal;
			sumTree[v] += addVal*(tr - tl + 1);
			return;
		}
		push(v, tl, tr);
		int tm = (tl + tr) / 2;
		if (l <= tm) {
			add(v + v, tl, tm, l, r, addVal);
		}
		if (r > tm) {
			add(v + v + 1, tm + 1, tr, l, r, addVal);
		}
		pull(v);
	}

	long long get(int v, int tl, int tr, int l, int r) {
		if (l <= tl && tr <= r) {
			return sumTree[v];
		}
		push(v, tl, tr);
		int tm = (tl + tr) / 2;
		long long res = 0;
		if (l <= tm) {
			res += get(v + v, tl, tm, l, r);
		}
		if (r > tm) {
			res += get(v + v + 1, tm + 1, tr, l, r);
		}
		return res;
	}
};

struct SegmentTreeMax {
	long long initVal[4 * N];
	long long addTree[4 * N];
	pair<long long, int> sumTree[4 * N];

	void pullMax(int v) {
		sumTree[v] = max(sumTree[v + v], sumTree[v + v + 1]);
	}

	void pull(int v) {
		pullMax(v);
	}

	void push(int v, int tl, int tr) {
		int tm = (tl + tr) / 2;
		long long addVal = addTree[v];
		addTree[v + v] += addVal;
		addTree[v + v + 1] += addVal;

		sumTree[v + v].first += addVal ;
		sumTree[v + v + 1].first += addVal;

		addTree[v] = 0;
	}

	void build(int v, int tl, int tr) {
		if (tl == tr) {
			sumTree[v] = make_pair(initVal[tl], tl);
			return;
		}
		int tm = (tl + tr) / 2;
		build(v + v, tl, tm);
		build(v + v + 1, tm + 1, tr);
		pull(v);
	}

	void add(int v, int tl, int tr, int l, int r, long long addVal) {
		if (l <= tl && tr <= r) {
			addTree[v] += addVal;
			sumTree[v].first += addVal;
			return;
		}
		push(v, tl, tr);
		int tm = (tl + tr) / 2;
		if (l <= tm) {
			add(v + v, tl, tm, l, r, addVal);
		}
		if (r > tm) {
			add(v + v + 1, tm + 1, tr, l, r, addVal);
		}
		pull(v);
	}

	pair<long long, int> get(int v, int tl, int tr, int l, int r) {
		if (l <= tl && tr <= r) {
			return sumTree[v];
		}
		push(v, tl, tr);
		int tm = (tl + tr) / 2;
		pair<long long, int> res(0, 0);
		bool taken = false;
		if (l <= tm) {
			pair<long long, int> newRes = get(v + v, tl, tm, l, r);
			if (res.second == 0 || res.first < newRes.first) {
				res = newRes;
			}
		}
		if (r > tm) {
			pair<long long, int> newRes = get(v + v + 1, tm + 1, tr, l, r);
			if (res.second == 0 || res.first < newRes.first) {
				res = newRes;
			}
		}
		return res;

	}
};

SegmentTreeMax valTree;
SegmentTree durTree;
//######################################################

int Q;
int queryType[N];
int queryTime[N];
int queryInd[N];
int queryDur[N];
int queryPos[N];

long long queryAnswer[N];

///
set<pair<int, int>> posCount;

void insert(int pos, int duration) {
//	cout << "insert " << pos << " " << duration << endl; //

	dur[pos] = duration;
	durTree.add(1, 1, n, pos, pos, duration);
	if (pos + 1 <= n) {
		valTree.add(1, 1, n, pos + 1, n, -duration);
	}
//	split(pos);
//	merge(pos);
}

void erase(int pos) {
//	cout << "erase " << pos << endl; //

	int duration = dur[pos];
	dur[pos] = 0;
	durTree.add(1, 1, n, pos, pos, -duration);
	if (pos + 1 <= n) {
		valTree.add(1, 1, n, pos + 1, n, duration);
	}
//	split(pos);
//	merge(pos);
}

long long findAnswer(int pos) {
//	cout << "find " << pos << endl; //

/*	set<pair<int, int>>::iterator it = findSetPos(pos);
	int lPos = it->first;
	int rPos = it->first + it->second - 1;
	return max(ti[lPos] + durTree.get(1, 1, n, lPos, pos) - ti[pos], (long long)0);*/
	int lPos = pos;
	pair<long long, int> crVal = valTree.get(1, 1, n, pos, pos);
	if (pos - 1 >= 1) {
		pair<long long, int> maxVal = valTree.get(1, 1, n, 1, pos - 1);
		if (maxVal.second != 0 && maxVal.first > crVal.first) {
			lPos = maxVal.second;
		}
	}
	return max(ti[lPos] + durTree.get(1, 1, n, lPos, pos) - ti[pos], (long long)0);
}

/// 
void printVals() {
	puts("Vals");
	for (int i = 1; i <= n; ++i) {
		cout << valTree.get(1, 1, n, i, i).first << " ";
	}
	puts("");
	for (int i = 1; i <= n; ++i) {
		cout << dur[i] << " ";
	}
	puts("");
}
///
void findQueryAnswers() {
	for (int i = 1; i <= n; ++i) {
		valTree.initVal[i] = ti[i];
	}
	valTree.build(1, 1, n);
	durTree.build(1, 1, n);
	durTree.type = 0;

	for (int i = 1; i <= n; ++i) {
		posCount.insert(make_pair(i, 1));
	}
//	printVals(); /// 
	for (int i = 1; i <= Q; ++i) {
		if (queryType[i] == 1) {
			insert(queryPos[i], queryDur[i]);
		}
		if (queryType[i] == -1) {
			erase(queryPos[i]);
		}
		if (queryType[i] == 0) {
			queryAnswer[i] = findAnswer(queryPos[i]);
		}
		//printVals(); /// 
	}
}

void solveMain() {
	scanf("%d", &Q);
	for (int i = 1; i <= Q; ++i) {
		char ty;
		scanf(" %c ", &ty);
		if (ty == '+') {
			queryType[i] = 1;
			scanf("%d%d", &queryTime[i], &queryDur[i]);
		}
		if (ty == '-') {
			queryType[i] = -1;
			scanf("%d", &queryInd[i]);
			queryTime[i] = queryTime[queryInd[i]];
		}
		if (ty == '?') {
			queryType[i] = 0;
			scanf("%d", &queryTime[i]);
		}
	}
	// Time, duration
	map<int, int> maTime;
	for (int i = 1; i <= Q; ++i) {
		maTime[queryTime[i]] = 0;
	}
	for (map<int, int>::iterator it = maTime.begin(); it != maTime.end(); ++it) {
		++n;
		it->second = n;
		ti[n] = it->first;
	}
	for (int i = 1; i <= Q; ++i) {
		queryPos[i] = maTime[queryTime[i]];
	}

	findQueryAnswers();
	for (int i = 1; i <= Q; ++i) {
		if (queryType[i] == 0) {
			printf("%lld\n", queryAnswer[i]);
		}
	}
}

int main() {
	//ios::sync_with_stdio(false);
	//freopen("input.txt", "r", stdin);
	solveMain();
	return 0;
}